# Masthay Helpers

![Masthay Helpers](https://edibleaspen.ediblecommunities.com/sites/default/files/images/article/hive-1.jpg)

This is a project for various helper functions to avoid repetitive 
implementation across projects.

## Table of Contents
- [Installation](#installation)

## Installation
Right now, I only support linux, but if you have linux, it's just a simple
install.
```bash
pip install masthay_helpers
